=====
OVP Users
=====

This module implements core user functionality.

Quick start
-----------
1. Install django-git-submodules::

    pip install ovp-users

2. Add it to `INSTALLED_APP` on `settings.py`


Forking
-----------
If you have your own OVP installation and want to fork this module
to implement custom features while still merging changes from upstream,
read Forking section on the wiki.
